# FAQ: Getting Help

## How do I do X? Why doesn’t Y work? Where can I go to get help?

First, please check if your question is answered on the FAQ.

We always welcome questions and feedback via our GitHub issue tracker:

 * [github.com/linkml/linkml/issues](https://github.com/linkml/linkml/issues)

## How do I request a feature or report a bug?

Please submit any bugs or feature requests to our tracker!

 * [github.com/linkml/linkml/issues](https://github.com/linkml/linkml/issues)

## Can I generate SHACL from a LinkML schema?

Not yet, but stay tuned!

## Can I generate classes for my favorite language from a LinkML schema?

Currently the emphasis is on generating Python dataclasses, but we
have java generators on the way, and can prioritize more on demand!

## For python generation, can I use pydantic instead of dataclasses?

Stay tuned!


